export default {
    "index": 20,
    "lineNumber": 1,
    "column": 21,
    "message": "Unexpected token \"foo\""
};